# coding: utf-8
XML_DEFINITION = '<?xml version="1.0" encoding="UTF-8" standalone="yes"?>'
